@@ -39,6 +39,7 @@ from .savedsearches import SavedSearchesMixin
 from .smartfilters import SmartfiltersMixin
 from .sources import SourcesMixin
 from .subscriptions import SubscriptionsMixin
+from .suggest_images import SuggestImageMixin
 from .synonyms import SynonymsMixin
 from .tasks import TasksMixin
 from .themes import ThemesMixin
@@ -54,7 +55,8 @@ class TopicApiBaseMixin:
         """Return all projects."""
         # Build URL
         url = "{ep}/v0/{tenant}/projects".format(
-            ep=self.topic_api_url, tenant=self.tenant,
+            ep=self.topic_api_url,
+            tenant=self.tenant,
         )
         res = self._perform_request("get", url)
         return self._process_response(res)
@@ -74,7 +76,8 @@ class TopicApiBaseMixin:
                             'name': 'textrazor'}]}
         """
         url = "{ep}/v0/{tenant}/pipelets".format(
-            ep=self.topic_api_url, tenant=self.tenant,
+            ep=self.topic_api_url,
+            tenant=self.tenant,
         )
         res = self._perform_request("get", url)
         return self._process_response(res)
@@ -95,7 +98,9 @@ class TopicApiBaseMixin:
              'source': 'from squirro.sdk.pipelet import PipeletV1\n\n\n...'}
         """
         url = "{ep}/v0/{tenant}/pipelets/{name}".format(
-            ep=self.topic_api_url, tenant=self.tenant, name=name,
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            name=name,
         )
         res = self._perform_request("get", url)
         return self._process_response(res)
@@ -111,7 +116,9 @@ class TopicApiBaseMixin:
             >>> client.delete_pipelet('textrazor')
         """
         url = "{ep}/v0/{tenant}/pipelets/{name}".format(
-            ep=self.topic_api_url, tenant=self.tenant, name=name,
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            name=name,
         )
         res = self._perform_request("delete", url)
         self._process_response(res, [204])
@@ -216,6 +223,7 @@ class TopicApiBaseMixin:
         options=None,
         encrypted_query=None,
         child_count=None,
+        timing: bool = False,
         **kwargs,
     ):
         """Returns items for the provided project.
@@ -262,6 +270,7 @@ class TopicApiBaseMixin:
             `created_before`.
         :param created_after: Restrict result set to items created after
             `created_after`.
+        :param timing: Boolean, specifies if detailed execution time profiling is reported (`True`). Disabled by default (`False`). The reported timing profile consists of a call stack with important subroutine execution times measured in milliseconds [ms]. If enabled, the report is returned with key `timing_report`.
         :param kwargs: Additional query parameters. All keyword arguments are
             passed on verbatim to the API.
 
@@ -337,6 +346,7 @@ class TopicApiBaseMixin:
             "created_before": created_before,
             "created_after": created_after,
             "encrypted_query": encrypted_query,
+            "timing": "true" if timing else None,  # timing parameter expects a str
         }
         if "scroll" in kwargs:
             logging.warning(
@@ -1598,7 +1608,7 @@ class TopicApiBaseMixin:
             # - The "content_phrase" suggester completes on key-phrases and item titles added by
             #  `NLP-Tagger <https://squirro.atlassian.net/wiki/spaces/DOC/pages/2396061784/Content-based+Typeahead>`__
             # - Autocompletion supports in-order phrase & fuzzy string matching
-            # - Highlighted tokens are returned as <b> html tags (highlight_cursor_start/end is not used)
+            # - Highlighted tokens are returned as <b> html tags
 
             >>> client.get_typeahead_suggestions(project_id=project_id,
                      searchbar_query="pla",
@@ -1610,16 +1620,12 @@ class TopicApiBaseMixin:
                      "key":" \"plant material\"",
                      "value":"<b>plant</b> material",
                      "group_name":"By Content",
-                     "highlight_cursor_start":0,
-                     "highlight_cursor_end":0
                   },
                   {
                      "type":"text",
                      "key":" \"plant proteins\"",
                      "value":"<b>plant</b> proteins",
                      "group_name":"By Content",
-                     "highlight_cursor_start":0,
-                     "highlight_cursor_end":0
                   }]
             }
 
@@ -1721,6 +1727,7 @@ class TopicApiMixin(
     SmartfiltersMixin,
     SourcesMixin,
     SubscriptionsMixin,
+    SuggestImageMixin,
     SynonymsMixin,
     TasksMixin,
     ThemesMixin,
