@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 import json
 import re
 
 
-class UserApiMixin(object):
+class UserApiMixin:
     """Mixin class which encapsulates the functionality of the user API
     service.
 
@@ -27,12 +26,12 @@ class UserApiMixin(object):
 
         """
 
-        url = "%(endpoint)s/%(version)s/%(tenant)s/users/%(user)s" % {
-            "endpoint": self.user_api_url,
-            "version": api_version,
-            "tenant": self.tenant,
-            "user": user_id,
-        }
+        url = "{endpoint}/{version}/{tenant}/users/{user}".format(
+            endpoint=self.user_api_url,
+            version=api_version,
+            tenant=self.tenant,
+            user=user_id,
+        )
         res = self._perform_request("get", url)
         return self._process_response(res)
 
@@ -56,12 +55,12 @@ class UserApiMixin(object):
 
         """
 
-        url = "%(endpoint)s/%(version)s/%(tenant)s/users/%(user)s" % {
-            "endpoint": self.user_api_url,
-            "version": api_version,
-            "tenant": self.tenant,
-            "user": user_id,
-        }
+        url = "{endpoint}/{version}/{tenant}/users/{user}".format(
+            endpoint=self.user_api_url,
+            version=api_version,
+            tenant=self.tenant,
+            user=user_id,
+        )
 
         if api_version == "v1":
             headers = {"Content-Type": "application/json"}
@@ -87,12 +86,12 @@ class UserApiMixin(object):
         """
         headers = {"Content-Type": "application/json"}
 
-        url = "%(endpoint)s/%(version)s/%(tenant)s/users/%(user)s/password" % {
-            "endpoint": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "user": user_id,
-        }
+        url = "{endpoint}/{version}/{tenant}/users/{user}/password".format(
+            endpoint=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            user=user_id,
+        )
 
         data = {
             "current_password": current_password,
@@ -105,11 +104,9 @@ class UserApiMixin(object):
 
     def get_users_password_policy(self):
         """Retrieve the password policy for users' passwords."""
-        url = "%(endpoint)s/%(version)s/%(tenant)s/users/password_policy" % {
-            "endpoint": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-        }
+        url = "{endpoint}/{version}/{tenant}/users/password_policy".format(
+            endpoint=self.user_api_url, version=self.version, tenant=self.tenant,
+        )
         res = self._perform_request("get", url)
         return self._process_response(res)
 
@@ -261,12 +258,12 @@ class UserApiMixin(object):
              u'refresh_token': u'b4c7440364afb80c2...14e2d538b0b773894ea2'}
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/users/%(user)s/grants" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "user": user_id,
-        }
+        url = "{ep}/{version}/{tenant}/users/{user}/grants".format(
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            user=user_id,
+        )
 
         params = {
             "type": type,
@@ -315,12 +312,12 @@ class UserApiMixin(object):
                           u'id': u'yL0dnd17RNe9Jpn7uAa8Bw', u'type': u'user'}]}
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/users/%(user)s/grants" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "user": user_id,
-        }
+        url = "{ep}/{version}/{tenant}/users/{user}/grants".format(
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            user=user_id,
+        )
 
         params = {"client_id": self.client_id, "client_secret": self.client_secret}
 
@@ -377,11 +374,9 @@ class UserApiMixin(object):
         if include_config is not None:
             params["include_config"] = include_config
 
-        url = "%(ep)s/%(version)s/%(tenant)s/users" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-        }
+        url = "{ep}/{version}/{tenant}/users".format(
+            ep=self.user_api_url, version=self.version, tenant=self.tenant,
+        )
 
         res = self._perform_request("get", url, params=params)
         return self._process_response(res, [200])
@@ -406,10 +401,7 @@ class UserApiMixin(object):
         if role:
             data["role"] = role
 
-        url = "%(ep)s/v0/%(tenant)s/users" % {
-            "ep": self.user_api_url,
-            "tenant": self.tenant,
-        }
+        url = f"{self.user_api_url}/v0/{self.tenant}/users"
 
         res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [201])
@@ -423,12 +415,12 @@ class UserApiMixin(object):
 
             >>> client.delete_user('H5Qv-WhgSBGW0WL8xolSCQ')
         """
-        url = "%(ep)s/%(version)s/%(tenant)s/users/%(user_id)s" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "user_id": user_id,
-        }
+        url = "{ep}/{version}/{tenant}/users/{user_id}".format(
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            user_id=user_id,
+        )
         res = self._perform_request("delete", url)
         return self._process_response(res, [204])
 
@@ -474,6 +466,29 @@ class UserApiMixin(object):
         res = self._perform_request("get", url)
         return self._process_response(res, [200])
 
+    def get_token_from_msexchuid(self, msexchuid):
+        """Retrieves the OAUTH2 authentication token for a given user based
+            on their MS Exchange UID (if it exists).
+
+        :param msexchuid: Microsoft Exchange UID
+        :returns: A dictionary containing the OAUTH2 token and the Squirro user id.
+
+        Example::
+
+            >>> client.get_token_from_msexchuid('89edf14d-90c4-834d-9efc-cd20a93fc74b')
+            {
+                u'oauth2_token': u'5ad37930dda85a7...6c066b2253dba8d19',
+                u'user_id': u'vP7h4g7EThuJKIfMorHTUQ',
+            }
+        """
+
+        url = ("%(ep)s/msexchange/oauth2_token") % {"ep": self.user_api_url}
+        params = {}
+        params["msexchuid"] = msexchuid
+
+        res = self._perform_request("get", url, params)
+        return self._process_response(res, [200])
+
     def add_project_member(self, project_id, role, user_id=None, group_id=None):
         """Adds a user or group to a project as a member.
 
@@ -603,11 +618,9 @@ class UserApiMixin(object):
              }
             ]
         """
-        url = "%(ep)s/%(version)s/%(tenant)s/groups" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-        }
+        url = "{ep}/{version}/{tenant}/groups".format(
+            ep=self.user_api_url, version=self.version, tenant=self.tenant,
+        )
         res = self._perform_request("get", url)
         return self._process_response(res, [200])
 
@@ -625,11 +638,9 @@ class UserApiMixin(object):
                 u'members': []
             }
         """
-        url = "%(ep)s/%(version)s/%(tenant)s/groups" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-        }
+        url = "{ep}/{version}/{tenant}/groups".format(
+            ep=self.user_api_url, version=self.version, tenant=self.tenant,
+        )
         res = self._perform_request("post", url, data={"name": name})
         return self._process_response(res, [201])
 
@@ -657,12 +668,12 @@ class UserApiMixin(object):
                 ]
             }
         """
-        url = "%(ep)s/%(version)s/%(tenant)s/groups/%(group)s" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "group": group_id,
-        }
+        url = "{ep}/{version}/{tenant}/groups/{group}".format(
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            group=group_id,
+        )
         res = self._perform_request("get", url)
         return self._process_response(res, [200])
 
@@ -690,12 +701,12 @@ class UserApiMixin(object):
                 ]
             }
         """
-        url = "%(ep)s/%(version)s/%(tenant)s/groups/%(group)s" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "group": group_id,
-        }
+        url = "{ep}/{version}/{tenant}/groups/{group}".format(
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            group=group_id,
+        )
         res = self._perform_request("put", url, data={"name": name})
         return self._process_response(res, [200])
 
@@ -708,12 +719,12 @@ class UserApiMixin(object):
 
             >>> client.delete_group('1jo-WmmyRvC8UYtPMIQaoQ')
         """
-        url = "%(ep)s/%(version)s/%(tenant)s/groups/%(group)s" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "group": group_id,
-        }
+        url = "{ep}/{version}/{tenant}/groups/{group}".format(
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            group=group_id,
+        )
         res = self._perform_request("delete", url)
         return self._process_response(res, [204])
 
@@ -736,12 +747,12 @@ class UserApiMixin(object):
                 u'tenant': 'lW8-FnZlQYWBimxFknYitw'
             }
         """
-        url = "%(ep)s/%(version)s/%(tenant)s/groups/%(group)s" % {
-            "ep": self.user_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "group": group_id,
-        }
+        url = "{ep}/{version}/{tenant}/groups/{group}".format(
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            group=group_id,
+        )
         res = self._perform_request("post", url, data={"user_id": user_id})
         return self._process_response(res, [200])
 
